using System;
using System.Linq;
using System.Windows.Forms;
using KellermanSoftware.NetEmailValidation;

namespace NetEmailValidationSimpleDemo
{
    public partial class frmMain : Form
    {
        private EmailValidation _valid;

        public frmMain()
        {
            InitializeComponent();
        }

        private void btnValidate_Click(object sender, EventArgs e)
        {
            if (!ValidateControls())
            {
                return;
            }               

            _valid.FromMailServer = txtFromEmailServer.Text;
            _valid.FromEmail = txtFromEmail.Text;
            Result myResult = _valid.ValidEmail(txtEmailAddress.Text,_valid.BestConnectionOptions());

            txtLog.Text = myResult.Log;

            if (myResult.IsValid)
                MessageBox.Show(myResult.UserMessage, "Valid Email", MessageBoxButtons.OK, MessageBoxIcon.Question);
            else
                MessageBox.Show(myResult.UserMessage, "Invalid Email", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            try
            {
                //This is trial mode
                _valid = new EmailValidation();

                //Example of licensed mode
                //_valid = new EmailValidation("place user name here from your receipt", "place license key here from your receipt"); 
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        private bool ValidateControls()
        {
            bool result = true;
            var controls = new[] { txtFromEmailServer, txtFromEmail, txtEmailAddress };
            foreach (var control in controls.Where(c => String.IsNullOrEmpty(c.Text)))
            {
                // clear previous errors
                errorProvider.SetError(control, "");                       
            }
            errorProvider.Clear();
            foreach (var control in controls.Where(c => String.IsNullOrEmpty(c.Text)))
            {
                errorProvider.SetError(control, "Please fill the required field");
                result = false;
            }
            return result;
        }
    }
}